@@ -1,5 +1,7 @@
 import weakref
 
+from functools import partial
+
 import bokeh
 import bokeh.core.properties as bp
 import param as pm
@@ -8,7 +10,9 @@ from bokeh.model import DataModel
 from bokeh.models import ColumnDataSource
 
 from ..reactive import Syncable
-from .notebook import push_on_root
+from .document import unlocked
+from .notebook import push
+from .state import state
 
 
 class Parameterized(bokeh.core.property.bases.Property):
@@ -192,13 +196,30 @@ def create_linked_datamodel(obj, root=None):
         }
         try:
             _changing.extend(list(update))
-            model.update(**update)
+
             tags = [tag for tag in model.tags if tag.startswith('__ref:')]
             if root:
-                push_on_root(root.ref['id'])
+                ref = root.ref['id']
             elif tags:
                 ref = tags[0].split('__ref:')[-1]
-                push_on_root(ref)
+            else:
+                ref = None
+
+            if ref and ref in state._views:
+                _, _, doc, comm = state._views[ref]
+                if comm or state._unblocked(doc):
+                    with unlocked():
+                        model.update(**update)
+                    if comm and 'embedded' not in root.tags:
+                        push(doc, comm)
+                else:
+                    cb = partial(model.update, **update)
+                    if doc.session_context:
+                        doc.add_next_tick_callback(cb)
+                    else:
+                        cb()
+            else:
+                model.update(**update)
         finally:
             for attr in update:
                 _changing.remove(attr)
