@@ -45,7 +45,7 @@ class comparable_array(np.ndarray):
     def __ne__(self, other: Any) -> bool:
         return not np.array_equal(self, other, equal_nan=True)
 
-def monkeypatch_events(events: List['DocumentChangedEvent']) -> None:
+def monkeypatch_events(events: List[DocumentChangedEvent]) -> None:
     """
     Patch events applies patches to events that are to be dispatched
     avoiding various issues in Bokeh.
@@ -66,7 +66,7 @@ def monkeypatch_events(events: List['DocumentChangedEvent']) -> None:
 #---------------------------------------------------------------------
 
 def diff(
-    doc: 'Document', binary: bool = True, events: Optional[List['DocumentChangedEvent']] = None
+    doc: Document, binary: bool = True, events: Optional[List[DocumentChangedEvent]] = None
 ) -> Message[Any] | None:
     """
     Returns a json diff required to update an existing plot with
@@ -92,7 +92,7 @@ def diff(
             msg.add_buffer(buffer)
     return msg
 
-def remove_root(obj: 'Model', replace: Optional['Document'] = None) -> None:
+def remove_root(obj: Model, replace: Document | None = None) -> None:
     """
     Removes the document from any previously displayed bokeh object
     """
@@ -104,7 +104,7 @@ def remove_root(obj: 'Model', replace: Optional['Document'] = None) -> None:
         if replace:
             model._document = replace
 
-def add_to_doc(obj: 'Model', doc: 'Document', hold: bool = False):
+def add_to_doc(obj: Model, doc: Document, hold: bool = False):
     """
     Adds a model to the supplied Document removing it from any existing Documents.
     """
@@ -114,24 +114,6 @@ def add_to_doc(obj: 'Model', doc: 'Document', hold: bool = False):
     if doc.callbacks.hold_value is None and hold:
         doc.hold()
 
-@contextmanager
-def hold(doc: 'Document', policy: 'HoldPolicyType' = 'combine', comm: Optional['Comm'] = None):
-    held = doc.callbacks.hold_value
-    try:
-        if policy is None:
-            doc.unhold()
-        else:
-            doc.hold(policy)
-        yield
-    finally:
-        if held:
-            doc.callbacks._hold = held
-        else:
-            if comm is not None:
-                from .notebook import push
-                push(doc, comm)
-            doc.unhold()
-
 def patch_cds_msg(model, msg):
     """
     Required for handling messages containing JSON serialized typed
@@ -149,7 +131,7 @@ def patch_cds_msg(model, msg):
 
 _DEFAULT_IGNORED_REPR = frozenset(['children', 'text', 'name', 'toolbar', 'renderers', 'below', 'center', 'left', 'right'])
 
-def bokeh_repr(obj: 'Model', depth: int = 0, ignored: Optional[Iterable[str]] = None) -> str:
+def bokeh_repr(obj: Model, depth: int = 0, ignored: Optional[Iterable[str]] = None) -> str:
     """
     Returns a string repr for a bokeh model, useful for recreating
     panel objects using pure bokeh.
@@ -184,3 +166,42 @@ def bokeh_repr(obj: 'Model', depth: int = 0, ignored: Optional[Iterable[str]] =
     else:
         r += '{cls}({props})'.format(cls=cls, props=props_repr)
     return r
+
+@contextmanager
+def hold(doc: Document, policy: HoldPolicyType = 'combine', comm: Comm | None = None):
+    """
+    Context manager that holds events on a particular Document
+    allowing them all to be collected and dispatched when the context
+    manager exits. This allows multiple events on the same object to
+    be combined if the policy is set to 'combine'.
+
+    Arguments
+    ---------
+    doc: Document
+        The Bokeh Document to hold events on.
+    policy: HoldPolicyType
+        One of 'combine', 'collect' or None determining whether events
+        setting the same property are combined or accumulated to be
+        dispatched when the context manager exits.
+    comm: Comm
+        The Comm to dispatch events on when the context manager exits.
+    """
+    doc = doc or state.curdoc
+    if doc is None:
+        yield
+        return
+    held = doc.callbacks.hold_value
+    try:
+        if policy is None:
+            doc.unhold()
+        else:
+            doc.hold(policy)
+        yield
+    finally:
+        if held:
+            doc.callbacks._hold = held
+        else:
+            if comm is not None:
+                from .notebook import push
+                push(doc, comm)
+            doc.unhold()
