@@ -14,6 +14,7 @@ from .reactive_html import ReactiveHTML  # noqa
 from .state import State  # noqa
 from .trend import TrendIndicator  # noqa
 from .widgets import (  # noqa
-    Audio, CustomSelect, FileDownload, Player, Progress, SingleSelect,
-    TooltipIcon, Video, VideoStream,
+    Audio, Button, CheckboxButtonGroup, CustomSelect, FileDownload, Player,
+    Progress, RadioButtonGroup, SingleSelect, TextAreaInput, TooltipIcon,
+    Video, VideoStream,
 )
