@@ -52,6 +52,32 @@ class TableEditEvent(ModelEvent):
             f'value={self.value}, old={self.old})'
         )
 
+class SelectionEvent(ModelEvent):
+
+    event_name = 'selection-change'
+
+    def __init__(self, model, indices, selected):
+        """ Selection Event
+
+        Parameters
+        ----------
+        model : ModelEvent
+            An event send when a selection is changed on the frontend.
+        indices : list[int]
+            A list of changed indices selected/deselected rows.
+        selected : bool
+            If true the rows were selected, if false they were deselected.
+        """
+        self.indices = indices
+        self.selected = selected
+        super().__init__(model=model)
+
+    def __repr__(self):
+        return (
+            f'{type(self).__name__}(indices={self.indices}, selected={self.selected})'
+        )
+
+
 class CellClickEvent(ModelEvent):
 
     event_name = 'cell-click'
