@@ -559,6 +559,19 @@ def test_tabulator_config_editor_dict(document, comm):
     assert model.configuration['columns'][2] == {'field': 'B', 'sorter': 'number', 'editor': 'list', 'editorParams': {'valuesLookup': True}}
 
 
+def test_tabulator_sortable_bool(dataframe, document, comm):
+    table = Tabulator(dataframe, sortable=False)
+    model = table.get_root(document, comm)
+    assert not any(col['headerSort'] for col in model.configuration['columns'])
+
+
+def test_tabulator_sortable_dict(dataframe, document, comm):
+    table = Tabulator(dataframe, sortable={'int': False})
+    model = table.get_root(document, comm)
+    assert all(not col['headerSort'] if col['field'] == 'int' else col['headerSort']
+               for col in model.configuration['columns'])
+
+
 def test_tabulator_groups(document, comm):
     df = makeMixedDataFrame()
     table = Tabulator(df, groups={'Number': ['A', 'B'], 'Other': ['C', 'D']})
@@ -2085,9 +2098,41 @@ def test_tabulator_formatter_update(dataframe, document, comm):
     model_formatter = model.columns[2].formatter
     assert model_formatter.format == formatter.format
 
+def test_tabulator_sortable_update(dataframe, document, comm):
+    table = Tabulator(dataframe, sortable={'int': False})
+    model = table.get_root(document, comm)
+    assert not model.configuration['columns'][1]['headerSort']
+
+    table.sortable = {'int': True, 'float': False}
+    assert model.configuration['columns'][1]['headerSort']
+    assert not model.configuration['columns'][2]['headerSort']
+
 def test_tabulator_hidden_columns_fix():
     # Checks for: https://github.com/holoviz/panel/issues/4102
     #             https://github.com/holoviz/panel/issues/5209
     table = Tabulator(pd.DataFrame(), show_index=False)
     table.hidden_columns = ["a", "b", "c"]
     assert table.hidden_columns == ["a", "b", "c"]
+
+@pytest.mark.parametrize('align', [{"x": "right"}, "right"], ids=["dict", "str"])
+def test_bokeh_formatter_with_text_align(align):
+    # https://github.com/holoviz/panel/issues/5807
+    data = pd.DataFrame({"x": [1.1, 2.0, 3.47]})
+    formatters = {"x": NumberFormatter(format="0.0")}
+    assert formatters["x"].text_align == "left"  # default
+    model = Tabulator(data, formatters=formatters, text_align=align)
+    columns = model._get_column_definitions("x", data)
+    output = columns[0].formatter.text_align
+    assert output == "right"
+
+@pytest.mark.parametrize('align', [{"x": "right"}, "right"], ids=["dict", "str"])
+def test_bokeh_formatter_with_text_align_conflict(align):
+    # https://github.com/holoviz/panel/issues/5807
+    data = pd.DataFrame({"x": [1.1, 2.0, 3.47]})
+    formatters = {"x": NumberFormatter(format="0.0", text_align="center")}
+    model = Tabulator(data, formatters=formatters, text_align=align)
+    msg = r"The 'text_align' in Tabulator\.formatters\['x'\] is overridden by Tabulator\.text_align"
+    with pytest.warns(RuntimeWarning, match=msg):
+        columns = model._get_column_definitions("x", data)
+    output = columns[0].formatter.text_align
+    assert output == "right"
