@@ -32,6 +32,7 @@ from ..util import (
     BOKEH_JS_NAT, clone_model, datetime_as_utctimestamp, isdatetime, lazy_load,
     styler_update, updating,
 )
+from ..util.warnings import warn
 from .base import Widget
 from .button import Button
 from .input import TextInput
@@ -43,7 +44,9 @@ if TYPE_CHECKING:
     from bokeh.models.sources import DataDict
     from pyviz_comms import Comm
 
-    from ..models.tabulator import CellClickEvent, TableEditEvent
+    from ..models.tabulator import (
+        CellClickEvent, SelectionEvent, TableEditEvent,
+    )
 
 
 def _convert_datetime_array_ignore_list(v):
@@ -176,34 +179,18 @@ class BaseTable(ReactiveData, Widget):
             col_kwargs = {}
             kind = data.dtype.kind
             editor: CellEditor
-            formatter: CellFormatter
+            formatter: CellFormatter | None = self.formatters.get(col)
             if kind == 'i':
-                formatter = NumberFormatter(text_align='right')
                 editor = IntEditor()
             elif kind == 'b':
-                formatter = StringFormatter(text_align='center')
                 editor = CheckboxEditor()
             elif kind == 'f':
-                formatter = NumberFormatter(format='0,0.0[00000]', text_align='right')
                 editor = NumberEditor()
             elif isdatetime(data) or kind == 'M':
-                if len(data) and isinstance(data.values[0], dt.date):
-                    date_format = '%Y-%m-%d'
-                else:
-                    date_format = '%Y-%m-%d %H:%M:%S'
-                formatter = DateFormatter(format=date_format, text_align='right')
                 editor = DateEditor()
             else:
-                formatter = StringFormatter()
                 editor = StringEditor()
 
-            if isinstance(self.text_align, str):
-                formatter.text_align = self.text_align
-            elif col in self.text_align:
-                formatter.text_align = self.text_align[col]
-            elif col in self.indexes:
-                formatter.text_align = 'left'
-
             if col in self.editors and not isinstance(self.editors[col], (dict, str)):
                 editor = self.editors[col]
                 if isinstance(editor, CellEditor):
@@ -212,10 +199,43 @@ class BaseTable(ReactiveData, Widget):
             if col in indexes or editor is None:
                 editor = CellEditor()
 
-            if col in self.formatters and not isinstance(self.formatters[col], (dict, str)):
-                formatter = self.formatters[col]
+            if formatter is None or isinstance(formatter, (dict, str)):
+                if kind == 'i':
+                    formatter = NumberFormatter(text_align='right')
+                elif kind == 'b':
+                    formatter = StringFormatter(text_align='center')
+                elif kind == 'f':
+                    formatter = NumberFormatter(format='0,0.0[00000]', text_align='right')
+                elif isdatetime(data) or kind == 'M':
+                    if len(data) and isinstance(data.values[0], dt.date):
+                        date_format = '%Y-%m-%d'
+                    else:
+                        date_format = '%Y-%m-%d %H:%M:%S'
+                    formatter = DateFormatter(format=date_format, text_align='right')
+                else:
+                    formatter = StringFormatter()
+
+                default_text_align = True
+            else:
                 if isinstance(formatter, CellFormatter):
                     formatter = clone_model(formatter)
+                if hasattr(formatter, 'text_align'):
+                    default_text_align = type(formatter).text_align.class_default(formatter) == formatter.text_align
+                else:
+                    default_text_align = True
+
+            if isinstance(self.text_align, str):
+                formatter.text_align = self.text_align
+                if not default_text_align:
+                    msg = f"The 'text_align' in Tabulator.formatters[{col!r}] is overridden by Tabulator.text_align"
+                    warn(msg, RuntimeWarning)
+            elif col in self.text_align:
+                formatter.text_align = self.text_align[col]
+                if not default_text_align:
+                    msg = f"The 'text_align' in Tabulator.formatters[{col!r}] is overridden by Tabulator.text_align[{col!r}]"
+                    warn(msg, RuntimeWarning)
+            elif col in self.indexes:
+                formatter.text_align = 'left'
 
             if isinstance(self.widths, int):
                 col_kwargs['width'] = self.widths
@@ -1099,6 +1119,11 @@ class Tabulator(BaseTable):
         A function which given a DataFrame should return a list of
         rows by integer index, which are selectable.""")
 
+    sortable = param.ClassSelector(default=True, class_=(bool, dict), doc="""
+        Whether the columns in the table should be sortable.
+        Can either be specified as a simple boolean toggling the behavior
+        on and off or as a dictionary specifying the option per column.""")
+
     theme = param.ObjectSelector(
         default="simple", objects=[
             'default', 'site', 'simple', 'midnight', 'modern', 'bootstrap',
@@ -1120,7 +1145,7 @@ class Tabulator(BaseTable):
     ]
 
     _config_params: ClassVar[List[str]] = [
-        'frozen_columns', 'groups', 'selectable', 'hierarchical'
+        'frozen_columns', 'groups', 'selectable', 'hierarchical', 'sortable'
     ]
 
     _content_params: ClassVar[List[str]] = _data_params + ['expanded', 'row_content', 'embed_content']
@@ -1132,7 +1157,8 @@ class Tabulator(BaseTable):
     _rename: ClassVar[Mapping[str, str | None]] = {
         'selection': None, 'row_content': None, 'row_height': None,
         'text_align': None, 'embed_content': None, 'header_align': None,
-        'header_filters': None, 'styles': 'cell_styles', 'title_formatters': None
+        'header_filters': None, 'styles': 'cell_styles',
+        'title_formatters': None, 'sortable': None
     }
 
     # Determines the maximum size limits beyond which (local, remote)
@@ -1217,7 +1243,11 @@ class Tabulator(BaseTable):
             p._cleanup(root)
         super()._cleanup(root)
 
-    def _process_event(self, event):
+    def _process_event(self, event) -> None:
+        if event.event_name == 'selection-change':
+            self._update_selection(event)
+            return
+
         event_col = self._renamed_cols.get(event.column, event.column)
         if self.pagination == 'remote':
             nrows = self.page_size
@@ -1237,7 +1267,7 @@ class Tabulator(BaseTable):
         if event.event_name == 'table-edit':
             if event.pre:
                 import pandas as pd
-                filter_df = pd.DataFrame([event.value], columns=[event.column])
+                filter_df = pd.DataFrame({event.column: [event.value]})
                 filters = self._get_header_filters(filter_df)
                 # Check if edited cell was filtered
                 if filters and filters[0].any():
@@ -1266,7 +1296,7 @@ class Tabulator(BaseTable):
     def _update_columns(self, event, model):
         if event.name not in self._config_params:
             super()._update_columns(event, model)
-            if (event.name in ('editors', 'formatters') and
+            if (event.name in ('editors', 'formatters', 'sortable') and
                 not any(isinstance(v, (str, dict)) for v in event.new.values())):
                 # If no tabulator editor/formatter was changed we can skip
                 # update to config
@@ -1507,6 +1537,12 @@ class Tabulator(BaseTable):
         elif events and all(e.name in page_events for e in events) and not self.pagination:
             self._processed, _ = self._get_data()
             return
+        elif (
+            self.pagination == 'remote'
+            and isinstance(self.selectable, str)
+            and "checkbox" in self.selectable
+        ):
+            self._processed = None
         recompute = not all(
             e.name in ('page', 'page_size', 'pagination') for e in events
         )
@@ -1533,20 +1569,23 @@ class Tabulator(BaseTable):
     def _update_selected(self, *events: param.parameterized.Event, indices=None):
         kwargs = {}
         if self.pagination == 'remote' and self.value is not None:
+            # Compute integer indexes of the selected rows
+            # on the displayed page
             index = self.value.iloc[self.selection].index
             indices = []
-            for v in index.values:
+            for ind in index.values:
                 try:
-                    iloc = self._processed.index.get_loc(v)
-                    self._validate_iloc(v ,iloc)
-                    indices.append(iloc)
+                    iloc = self._processed.index.get_loc(ind)
+                    self._validate_iloc(ind ,iloc)
+                    indices.append((ind, iloc))
                 except KeyError:
                     continue
             nrows = self.page_size
             start = (self.page-1)*nrows
             end = start+nrows
-            kwargs['indices'] = [ind-start for ind in indices
-                                 if ind>=start and ind<end]
+            p_range = self._processed.index[start:end]
+            kwargs['indices'] = [iloc - start for ind, iloc in indices
+                                 if ind in p_range]
         super()._update_selected(*events, **kwargs)
 
     def _update_column(self, column: str, array: np.ndarray):
@@ -1567,22 +1606,32 @@ class Tabulator(BaseTable):
         with pd.option_context('mode.chained_assignment', None):
             self._processed.loc[index, column] = array
 
-    def _update_selection(self, indices: List[int]):
+    def _update_selection(self, indices: List[int] | SelectionEvent):
         if self.pagination != 'remote':
             self.selection = indices
             return
+        if isinstance(indices, list):
+            selected = True
+            ilocs = []
+        else:  # SelectionEvent
+            selected = indices.selected
+            indices = indices.indices
+            ilocs = self.selection
+
         nrows = self.page_size
         start = (self.page-1)*nrows
         index = self._processed.iloc[[start+ind for ind in indices]].index
-        indices = []
         for v in index.values:
             try:
                 iloc = self.value.index.get_loc(v)
                 self._validate_iloc(v, iloc)
-                indices.append(iloc)
             except KeyError:
                 continue
-        self.selection = indices
+            if selected:
+                ilocs.append(iloc)
+            else:
+                ilocs.remove(iloc)
+        self.selection = list(dict.fromkeys(ilocs))
 
     def _get_properties(self, doc: Document) -> Dict[str, Any]:
         properties = super()._get_properties(doc)
@@ -1634,7 +1683,7 @@ class Tabulator(BaseTable):
             child_panels, doc, root, parent, comm
         )
         self._link_props(model, ['page', 'sorters', 'expanded', 'filters'], doc, root, comm)
-        self._register_events('cell-click', 'table-edit', model=model, doc=doc, comm=comm)
+        self._register_events('cell-click', 'table-edit', 'selection-change', model=model, doc=doc, comm=comm)
         return model
 
     def _get_filter_spec(self, column: TableColumn) -> Dict[str, Any]:
@@ -1738,39 +1787,44 @@ class Tabulator(BaseTable):
             for group, group_cols in self.groups.items()
         }
         for i, column in enumerate(ordered):
+            field = column.field
             matching_groups = [
                 group for group, group_cols in grouping.items()
-                if column.field in group_cols
+                if field in group_cols
             ]
-            col_dict = {'field': column.field}
+            col_dict = dict(field=field)
+            if isinstance(self.sortable, dict):
+                col_dict['headerSort'] = self.sortable.get(field, True)
+            elif not self.sortable:
+                col_dict['headerSort'] = self.sortable
             if isinstance(self.text_align, str):
                 col_dict['hozAlign'] = self.text_align
-            elif column.field in self.text_align:
-                col_dict['hozAlign'] = self.text_align[column.field]
+            elif field in self.text_align:
+                col_dict['hozAlign'] = self.text_align[field]
             if isinstance(self.header_align, str):
                 col_dict['headerHozAlign'] = self.header_align
-            elif column.field in self.header_align:
-                col_dict['headerHozAlign'] = self.header_align[column.field]
-            formatter = self.formatters.get(column.field)
+            elif field in self.header_align:
+                col_dict['headerHozAlign'] = self.header_align[field]
+            formatter = self.formatters.get(field)
             if isinstance(formatter, str):
                 col_dict['formatter'] = formatter
             elif isinstance(formatter, dict):
                 formatter = dict(formatter)
                 col_dict['formatter'] = formatter.pop('type')
                 col_dict['formatterParams'] = formatter
-            title_formatter = self.title_formatters.get(column.field)
+            title_formatter = self.title_formatters.get(field)
             if title_formatter:
                 col_dict['titleFormatter'] = title_formatter
             elif isinstance(title_formatter, dict):
                 formatter = dict(title_formatter)
                 col_dict['titleFormatter'] = title_formatter.pop('type')
                 col_dict['titleFormatterParams'] = title_formatter
-            col_name = self._renamed_cols[column.field]
-            if column.field in self.indexes:
+            col_name = self._renamed_cols[field]
+            if field in self.indexes:
                 if len(self.indexes) == 1:
                     dtype = self.value.index.dtype
                 else:
-                    dtype = self.value.index.get_level_values(self.indexes.index(column.field)).dtype
+                    dtype = self.value.index.get_level_values(self.indexes.index(field)).dtype
             else:
                 dtype = self.value.dtypes[col_name]
             if dtype.kind == 'M':
@@ -1779,8 +1833,8 @@ class Tabulator(BaseTable):
                 col_dict['sorter'] = 'number'
             elif dtype.kind == 'b':
                 col_dict['sorter'] = 'boolean'
-            editor = self.editors.get(column.field)
-            if column.field in self.editors and editor is None:
+            editor = self.editors.get(field)
+            if field in self.editors and editor is None:
                 col_dict['editable'] = False
             if isinstance(editor, str):
                 col_dict['editor'] = editor
@@ -1791,16 +1845,16 @@ class Tabulator(BaseTable):
             if col_dict.get('editor') in ['select', 'autocomplete']:
                 self.param.warning(
                     f'The {col_dict["editor"]!r} editor has been deprecated, use '
-                    f'instead the "list" editor type to configure column {column.field!r}'
+                    f'instead the "list" editor type to configure column {field!r}'
                 )
                 col_dict['editor'] = 'list'
                 if col_dict.get('editorParams', {}).get('values', False) is True:
                     del col_dict['editorParams']['values']
                     col_dict['editorParams']['valuesLookup']
-            if column.field in self.frozen_columns or i in self.frozen_columns:
+            if field in self.frozen_columns or i in self.frozen_columns:
                 col_dict['frozen'] = True
-            if isinstance(self.widths, dict) and isinstance(self.widths.get(column.field), str):
-                col_dict['width'] = self.widths[column.field]
+            if isinstance(self.widths, dict) and isinstance(self.widths.get(field), str):
+                col_dict['width'] = self.widths[field]
             col_dict.update(self._get_filter_spec(column))
             if matching_groups:
                 group = matching_groups[0]
